#
# spec file for package kdebugsettings
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.3.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kdebugsettings
Version:        24.08.2
Release:        1.1
Summary:        Program to set debug verbosity for KDE applications
License:        LGPL-2.0-or-later
URL:            https://apps.kde.org/kdebugsettings
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemViews) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Obsoletes:      kdebugsettings5 < %{version}
Provides:       kdebugsettings5 = %{version}

%description
This program allows to tune the debug output of KDE applications, ranging
from verbose to completely silent.

%lang_package

%prep
%autosetup -p1 -n kdebugsettings-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%suse_update_desktop_file org.kde.kdebugsettings Utility DesktopUtility

%ldconfig_scriptlets

%files
%license LICENSES/*
%{_kf6_applicationsdir}/org.kde.kdebugsettings.desktop
%{_kf6_appstreamdir}/org.kde.kdebugsettings.appdata.xml
%{_kf6_bindir}/kdebugsettings
%{_kf6_debugdir}/kde.renamecategories
%{_kf6_debugdir}/kdebugsettings.categories
%{_kf6_libdir}/libkdebugsettings.so.*
%{_kf6_libdir}/libkdebugsettingscore.so.*
%{_kf6_sharedir}/kdebugsettings/

%files lang -f %{name}.lang

%changelog
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * snapcraft: Release from release branch.
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Time to increase version
  * Use @info:placeholder
  * make filter case-insensitive
  * Fix dependancies
  * IconTheme is searched by default
  * Fix cmakelint warning
  * Add developer name to appdata
  * Add @action:button
  * Don't export private methods
  * Fix warning
  * It compiles fine without deprecated methods
  * Fix 488354:  "Enable" and "Turn Off" buttons should act on selected entries only (kde#488354)
  * Don't include when HAVE_DBUSADDONS is false
  * Add missing require
  * Disable DBusAddons on windows
  * Add build-ftime support
  * Add @label:textbox
  * Use KIconThemes and KStyleManager if available during build-time
  * Add contect
  * Use ellipsis character instead of three dots in UI strings
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Don't export private symbol
  * Add missing [[nodiscard]]
  * Port deprecated [=]
  * It compiles fine without deprecated methods
  * Depend against last qt version
  * Remove qml version
  * Replace Kirigami.BasicListItem
  * Use constexpr
  * USe _L1
  * Use desktop-application
  * Add more CI build
  * Add cppcheck support
  * Add vcs-browser
  * Drop support for KF5's deprecated KToolInvocation
  * It compiles fine without deprecated method
  * Fix url (use qt6 path)
  * we use QT_REQUIRED_VERSION here
  * Optimization
  * Fix typo
  * Add a homepage to appdata to satisfy CI
  * Output rules that override all others at the top of the save file
  * Better wording for the CategoryWarning message
  * Ensure that the CategoryWarning is shown, if relevant, on first startup
  * Eliminate annoying "declaration shadows a member" warnings
  * Use QLatin1StringView directly
  * [CI] Add Flatpak
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Add a homepage to appdata to satisfy CI
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Add snapcraft.yaml to reuse dep5
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes to list here.
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Thu Mar 16 2023 Christophe Marin <christophe@krop.fr>
- Use the %%ldconfig_scriptlets macro
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Fix show headers in qtc6
  * Use directly Qt::
  * Use ecm_set_disabled_deprecation_versions
  * Use new reuse-lint
  * Add support for debug categories in qt6
  * Use SingleMainWindow=true
  * Add unity build support
  * Try to activate qt6 CI support
  * We need 5.90 for building against qt6
  * Mark as single-instance using X-GNOME-SingleWindow key
  * Allow to compile against qt6
  * Add asan support
  * Fix some licenses problem
  * Fix typo
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Allow to show header in qtc6
  * Add dialog when we inserted categories
  * Add missing license file
  * It's autogenerated
  * Use camel case includes
  * Fix i18n
  * Time to increase version
  * Autogenerated
  * Minor optimization
  * Fix clazy warning
  * Fix clazy exclude name
  * Const'ify variable
  * Revert "Use actually released versions with *_DISABLE_DEPRECATED"
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Fix list of group name
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Make sure to create directory group
  * Don't return error when we cancel dialog
  * Fix icons
  * Avoid to close dialogbox when we press enter/return
  * We don't install it => don't report warning
  * Add clang support
  * Use actually released versions with *_DISABLE_DEPRECATED
  * Check Qt5Test only if we build test
  * Time to increase version
  * More target support
  * We don't have extra source
  * Download missing licenses
  * Fix clazy warning
  * gitlab-ci: Use Qt 5.15 in clazy job
  * Add build preset support + clazy support
  * It's autogenerated
  * Use openStateConfig for storing window size
  * Add message error when we can't save as empty name
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Changes since 20.08.3:
  * Modernize code
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Remove explicit ECM_KDE_MODULE_DIR
  * Time to increase version
  * Start to implement group support
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * Don't export QT_HASH_SEED and QT_NO_CPU_FEATURE anymore
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Changes since 20.04.3:
  * Fix clazy compile
  * Exclude it
  * Fix gitlab
  * Add file extension
  * We depend against 5.68 now
  * Fix warning found by cppcheck
  * Readd it I maintain it so it's my problem
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * Fix some clazy warning
  * Set application display name to non-lowercase variant (& typo fixed)
  * Use new macro for autogenerating categories file
  * Clean reference to log_kdepassword
  * Ignore files
  * Make it compiles against qt5.15 (endl other other use Qt:: namespace now)
  * Add @title:window
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes to list here.
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Use new syntax
  * It doesn't exist
  * Move in own file
  * Clean up includes
  * Remove not necessary include
  * Clean up code.
  * Use new locations
  * We will depend against 5.59
  * Continue to use new folder for logging category files
  * Prepare using KDE_INSTALL_LOGGINGCATEGORIESDIR
  * Remove duplicate code
  * Minor optimization
  * Update kf5 version
  * It's already defined in default compile flags
  * increase dependency
  * increase cmake version
  * Fix clazy warning
* Thu Jul 18 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use kf5_debugdir macro for specifying the logging categories location
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Fix compile
  * Load new logging category directory
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Convert to camelcase include
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Check version of kconfig
  * Make it compile without foreach
  * Make it compile against qt5.13
  * Exclude more files
  * Use https here
  * Add warning about old syntax
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Add gitignore
  * Fix backport
  * Force forcus to lineedit
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * the default setting for kf5.kcoreaddons.desktopparser is actually Warning
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Time to increase it
  * Use strict compile flags
  * Remove usage of dead QT_USE_FAST_CONCATENATION
  * Use Q_REQUIRED_RESULT
  * Allow to disable all debug messages
  * Rename method
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Disable only debug message as requested by david
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Add category name as tooltip.
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Fix save custom rules when value is false
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Debug goes above Info.
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Don't repeat work of KAboutData::setupCommandLine().
  * Add parent
  * Move as private method
  * Initialize pointer
  * Assign parent directly
  * USe version to project
  * add icon for appstream compliance http://metadata.neon.kde.org/appstream/html/xenial/main/issues/kdebugsettings.html
  * add comment for appstream compliance http://metadata.neon.kde.org/appstream/html/xenial/main/issues/kdebugsettings.html
  * Use NoDisplay not Hidden=true
  * Avoid to create config in .config
  * Signal if we can't see default file
  * Fix using it when uninstalled
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * add missing category
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Make focus to lineedit
  * Use override
  * Make sure to not using deprecated method
  * increase version
  * port to for(...:...)
  * We depend against qt5.7
  * Adapt lskat category
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Use document()->isEmpty()
  * Enable the Debug level when enabling "all debug"
  * update copyright
  * use nullptr
  * increase minimum qt version
  * increase version
  * Port to for(...:...)
  * Port to for(...:...)
  * Start to port some Q_FOREACH
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * support loading qtlogging.ini from QLibraryInfo::DataPath too
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
- Drop upstream patch fix-license-file.diff
* Tue Aug 25 2015 cgiboudeaux@gmx.com
- Fix the URL tag.
* Tue Aug 25 2015 cgiboudeaux@gmx.com
- Add fix-license-file.diff. kdebugsettings is LGPL-2.0+
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Initial version based on KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
